package betterquesting.client.toolbox;

import betterquesting.api.client.toolbox.IToolboxTool;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.lists.CanvasQuestLine;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.themes.presets.PresetIcon;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.editors.designer.PanelToolController;
import betterquesting.client.gui2.editors.nbt.GuiNbtEditor;
import betterquesting.client.toolbox.tools.ToolboxToolComplete;
import betterquesting.client.toolbox.tools.ToolboxToolCopy;
import betterquesting.client.toolbox.tools.ToolboxToolDelete;
import betterquesting.client.toolbox.tools.ToolboxToolFrame;
import betterquesting.client.toolbox.tools.ToolboxToolGrab;
import betterquesting.client.toolbox.tools.ToolboxToolIcon;
import betterquesting.client.toolbox.tools.ToolboxToolLink;
import betterquesting.client.toolbox.tools.ToolboxToolNew;
import betterquesting.client.toolbox.tools.ToolboxToolOpen;
import betterquesting.client.toolbox.tools.ToolboxToolRemove;
import betterquesting.client.toolbox.tools.ToolboxToolReset;
import betterquesting.client.toolbox.tools.ToolboxToolScale;
import betterquesting.network.handlers.NetChapterEdit;
import betterquesting.questing.QuestLineDatabase;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.client.Minecraft;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.EnumChatFormatting;

/* loaded from: betterquesting_client_toolbox.jar:betterquesting/client/toolbox/PanelTabMain.class */
public class PanelTabMain extends CanvasEmpty {
    private final CanvasQuestLine cvQuestLine;
    private final PanelToolController toolController;
    private static final List<ToolEntry> toolEntries = new ArrayList();

    static {
        toolEntries.add(new ToolEntry(new ToolboxToolOpen(), PresetIcon.ICON_CURSOR.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.open.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.open.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolNew(), PresetIcon.ICON_NEW.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.new.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.new.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolGrab(), PresetIcon.ICON_GRAB.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.grab.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.grab.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolLink(), PresetIcon.ICON_LINK.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.link.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.link.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolCopy(), PresetIcon.ICON_COPY.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.copy.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.copy.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolScale(), PresetIcon.ICON_SCALE.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.scale.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.scale.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolDelete(), PresetIcon.ICON_TRASH.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.delete.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.delete.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolRemove(), PresetIcon.ICON_NEGATIVE.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.remove.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.remove.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolComplete(), PresetIcon.ICON_TICK.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.complete.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.complete.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolReset(), PresetIcon.ICON_REFRESH.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.reset.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.reset.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolIcon(), PresetIcon.ICON_ITEM.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.icon.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.icon.desc", new Object[0]))));
        toolEntries.add(new ToolEntry(new ToolboxToolFrame(), PresetIcon.ICON_NOTICE.getTexture(), makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.frame.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.frame.desc", new Object[0]))));
    }

    public PanelTabMain(IGuiRect rect, CanvasQuestLine cvQuestLine, PanelToolController toolController) {
        super(rect);
        this.cvQuestLine = cvQuestLine;
        this.toolController = toolController;
    }

    /* JADX WARN: Type inference failed for: r1v1, types: [betterquesting.client.toolbox.PanelTabMain$1] */
    /* JADX WARN: Type inference failed for: r1v6, types: [betterquesting.client.toolbox.PanelTabMain$2] */
    public void initPanel() {
        super.initPanel();
        int w = getTransform().getWidth();
        GuiColorStatic guiColorStatic = new GuiColorStatic(-16777216);
        addPanel(new PanelButton(new GuiRectangle(0, 0, w / 2, 16, 0), -1, "" + ToolboxTabMain.INSTANCE.getSnapValue()) { // from class: betterquesting.client.toolbox.PanelTabMain.1
            public void onButtonClick() {
                ToolboxTabMain.INSTANCE.toggleSnap();
                setText("" + ToolboxTabMain.INSTANCE.getSnapValue());
            }
        }.setIcon(PresetIcon.ICON_GRID.getTexture()).setTextShadow(false).setTextHighlight(guiColorStatic, guiColorStatic, guiColorStatic).setTooltip(makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.snap.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.snap.desc", new Object[0]))));
        addPanel(new PanelButton(new GuiRectangle(w / 2, 0, w / 2, 16, 0), -1, "") { // from class: betterquesting.client.toolbox.PanelTabMain.2
            public void onButtonClick() {
                Minecraft mc = Minecraft.func_71410_x();
                mc.func_147108_a(new GuiNbtEditor(mc.field_71462_r, PanelTabMain.this.cvQuestLine.getQuestLine().writeToNBT(new NBTTagCompound(), (List) null), value -> {
                    NBTTagCompound payload = new NBTTagCompound();
                    NBTTagList dataList = new NBTTagList();
                    NBTTagCompound entry = new NBTTagCompound();
                    entry.func_74768_a("chapterID", QuestLineDatabase.INSTANCE.getID(PanelTabMain.this.cvQuestLine.getQuestLine()));
                    entry.func_74782_a("config", value);
                    dataList.func_74742_a(entry);
                    payload.func_74782_a("data", dataList);
                    payload.func_74768_a("action", 0);
                    NetChapterEdit.sendEdit(payload);
                }));
            }
        }.setIcon(PresetIcon.ICON_PROPS.getTexture()).setTooltip(makeToolTip(QuestTranslation.translate("betterquesting.toolbox.tool.raw.name", new Object[0]), QuestTranslation.translate("betterquesting.toolbox.tool.raw.desc", new Object[0]))));
        List<PanelButtonStorage<IToolboxTool>> toolBtns = new ArrayList<>();
        for (int i = 0; i < toolEntries.size(); i++) {
            ToolEntry entry = toolEntries.get(i);
            int x = (i % 2) * (w / 2);
            int y = ((i / 2) * 16) + 24;
            PanelButtonStorage<IToolboxTool> btn = new PanelButtonStorage<>(new GuiRectangle(x, y, w / 2, 16, 0), -1, "", entry.tool);
            btn.setActive(this.toolController.getActiveTool() != entry.tool);
            btn.setIcon(entry.tex).setTooltip(entry.tt);
            btn.setCallback(value -> {
                this.toolController.setActiveTool(value);
                toolBtns.forEach(b -> {
                    b.setActive(true);
                });
                btn.setActive(false);
            });
            toolBtns.add(btn);
            addPanel(btn);
            if ((entry.tool instanceof ToolboxToolOpen) && this.toolController.getActiveTool() == null) {
                this.toolController.setActiveTool(entry.tool);
                btn.setActive(false);
            }
        }
    }

    private static List<String> makeToolTip(String title, String desc) {
        List<String> list = new ArrayList<>();
        list.add(title);
        list.addAll(Minecraft.func_71410_x().field_71466_p.func_78271_c(EnumChatFormatting.GRAY + desc, 128));
        return list;
    }

    /* loaded from: betterquesting_client_toolbox.jar:betterquesting/client/toolbox/PanelTabMain$ToolEntry.class */
    private static class ToolEntry {
        private final IToolboxTool tool;
        private final IGuiTexture tex;
        private final List<String> tt;

        private ToolEntry(IToolboxTool tool, IGuiTexture tex, List<String> tt) {
            this.tool = tool;
            this.tex = tex;
            this.tt = tt;
        }
    }
}
